Highlight

Struct Highlight 

pub struct Highlight {
    pub title: Option<String>,
    pub icon: Option<String>,
    pub body: Vec<Paragraph>,
}
Highlight

Must start and end with Bang of length 2.

Title is sequence of tokens between first Bang of length 2 followed by Space and Eol. Can be omitted.

Icon is sequence of tokens between Bang of length 1 followed by Space and Eol. Can be omitted.

Title and Icon can not contain Terminator.

Body is one or more Paragraph’s.

Example:

!! Tile
! Icon
body
!!

Example without title:

!!
! Icon
body
!!

Example without icon:

!! Tile
body
!!

Fields

title: Option<String>icon: Option<String>body: Vec<Paragraph>

Implementations

Source

impl Highlight

pub fn new<T: Into<String>, I: Into<String>>( title: Option<T>, icon: Option<I>, body: Vec<Paragraph>, ) -> Self